@@ -1,7 +1,7 @@
 package URI::urn::uuid;
 
 use strict;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use base qw(URI::urn);
 use Data::UUID;
@@ -37,6 +37,9 @@ URI::urn::uuid - UUID URN Namespace
   $uri->uuid;        # f81d4fae-7dec-11d0-a765-00a0c91e6bf6
   $uri->uuid_binary; # in 128 bit binary form of Data::UUID
 
+  $uri = URI->new("urn:uuid:");
+  $uri->uuid( lc Data::UUID->new->create_str );
+
 =head1 DESCRIPTION
 
 URI::urn::uuid is an URI class that implement UUID URN namespace.
